@@ -1,7 +1,7 @@
 context("Truncated matrix")
 
 test_that("interface of print() identical to trunc_mat()", {
-  print_arg_names <- names(formals(print.tbl_df))
+  print_arg_names <- names(formals(print.tbl))
   print_arg_names_without_ellipsis <- setdiff(print_arg_names, "...")
 
   trunc_mat_arg_names <- names(formals(trunc_mat))
@@ -79,6 +79,10 @@ test_that("trunc_mat output matches known output", {
     print(trunc_mat(df_all, n = 1L, n_extra = 0L, width = 30L)),
     "trunc_mat/all-1-30-0.txt")
 
+  expect_output_file_rel(
+    print(trunc_mat(tibble(`\n` = c("\n", '"')))),
+    "trunc_mat/newline.txt")
+
   expect_output_knit(
     knitr::knit_print(trunc_mat(df_all, width = 60L)),
     "trunc_mat/all-knit-60.txt")
@@ -104,9 +108,9 @@ test_that("trunc_mat for POSIXlt columns (#86)", {
 })
 
 test_that("trunc_mat for wide-character columns (#100)", {
-  skip_on_os("windows")
+  skip_on_os("windows") # capture_output_lines() forces native encoding
 
-  x <- c("成交日期", "合同录入日期")
+  x <- c("\u6210\u4ea4\u65e5\u671f", "\u5408\u540c\u5f55\u5165\u65e5\u671f")
   df <- setNames(tibble(1:3, 4:6), x)
 
   expect_output_file_rel(
@@ -114,6 +118,19 @@ test_that("trunc_mat for wide-character columns (#100)", {
     "trunc_mat/wide-8-60.txt")
 })
 
+test_that("trunc_mat for wide-character columns in non-UTF-8 locale", {
+  skip_on_os("windows") # capture_output_lines() forces native encoding
+
+  with_non_utf8_locale({
+    x <- c("\u6210\u4ea4\u65e5\u671f", "\u5408\u540c\u5f55\u5165\u65e5\u671f")
+    df <- setNames(tibble(1:3, 4:6), x)
+
+    expect_output_file_rel(
+      print(df, n = 8L, width = 60L),
+      "trunc_mat/wide-8-60.txt")
+  })
+})
+
 test_that("trunc_mat backticks non-syntactic names", {
   tb <- tibble(
     `:)` = "smile",
